@@ -4,3 +4,6 @@ try:
     from .version import __version__
 except ImportError:
     __version__ = 'master'
+
+# Always initialize HAL, otherwise segfaults can happen
+HALInitialize()
